@@ -17,7 +17,7 @@ use Data::Compare; # Exports Compare()
 $Storable::Deparse  = 1;
 $Storable::Eval     = 1;
 
-our $VERSION = '0.4';
+our $VERSION = '0.41';
 
 use Class::Tiny {
     registry        => sub {{}},
@@ -135,7 +135,7 @@ EventStore::Tiny - A minimal event sourcing framework.
 
 =begin html
 
-<p>
+<p style="line-height: 190%">
 
 <a href="https://badge.fury.io/pl/EventStore-Tiny">
     <img alt="CPAN version" src="https://badge.fury.io/pl/EventStore-Tiny.svg"></a>
